@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-sqlite
 version: 2.2.1
-id: persistent-sqlite-2.2.1-528dd876cba8e032d04bda7aa027dfdb
-key: persi_EKRiMQzuroCJfNGv8Gk3xe
+id: persistent-sqlite-2.2.1-020805a595e48e0f78227359194c2b5e
+key: persi_BMj2j1IM1QsGyjc3vOgZHH
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,7 +20,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2.1
-hs-libraries: HSpersistent-sqlite-2.2.1-EKRiMQzuroCJfNGv8Gk3xe
+hs-libraries: HSpersistent-sqlite-2.2.1-BMj2j1IM1QsGyjc3vOgZHH
 extra-libraries:
     pthread
 depends:
@@ -30,9 +30,9 @@ depends:
     conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
-    monad-logger-0.3.18-0092336dcf2d8f29e67bd77a9cfcb547
+    monad-logger-0.3.18-d371de410ef611b2a9194c84cfcdfbf6
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    persistent-2.2.4.1-06cdd104cf52ce01e8563b1ef8106c7c
+    persistent-2.2.4.1-840a8f388c4f74e927e97d9dd2d8494d
     resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
